@@ -17,6 +17,8 @@ from __future__ import annotations
 
 import operator
 from enum import IntEnum
+import warnings
+
 from ._creation_functions import asarray
 from ._dtypes import (
     _DType,
@@ -122,14 +124,26 @@ class Array:
 
     # This function is not required by the spec, but we implement it here for
     # convenience so that np.asarray(array_api_strict.Array) will work.
-    def __array__(self, dtype: None | np.dtype[Any] = None) -> npt.NDArray[Any]:
+    def __array__(self, dtype: None | np.dtype[Any] = None, copy: None | bool = None) -> npt.NDArray[Any]:
         """
         Warning: this method is NOT part of the array API spec. Implementers
         of other libraries need not include it, and users should not assume it
         will be present in other implementations.
 
         """
-        return np.asarray(self._array, dtype=dtype)
+        # copy keyword is new in 2.0.0; for older versions don't use it
+        # retry without that keyword.
+        if np.__version__[0] < '2':
+            return np.asarray(self._array, dtype=dtype)
+        elif np.__version__.startswith('2.0.0-dev0'):
+            # Handle dev version for which we can't know based on version
+            # number whether or not the copy keyword is supported.
+            try:
+                return np.asarray(self._array, dtype=dtype, copy=copy)
+            except TypeError:
+                return np.asarray(self._array, dtype=dtype)
+        else:
+            return np.asarray(self._array, dtype=dtype, copy=copy)
 
     # These are various helper functions to make the array behavior match the
     # spec in places where it either deviates from or is more strict than
@@ -468,8 +482,10 @@ class Array:
     def __array_namespace__(
         self: Array, /, *, api_version: Optional[str] = None
     ) -> types.ModuleType:
-        if api_version is not None and not api_version.startswith("2021."):
+        if api_version is not None and api_version not in ["2021.12", "2022.12"]:
             raise ValueError(f"Unrecognized array API version: {api_version!r}")
+        if api_version == "2021.12":
+            warnings.warn("The 2021.12 version of the array API specification was requested but the returned namespace is actually version 2022.12")
         import array_api_strict
         return array_api_strict
 
